## START: Set by rpmautospec
## (rpmautospec version 0.6.0)
## RPMAUTOSPEC: autochangelog
## END: Set by rpmautospec

%global longver 2024-02-01
%global shortver %(echo %{longver}|sed 's|-||g')

Name:           re2
Version:        %{shortver}
Epoch:          1
Release:        1%{?dist}
Summary:        C++ fast alternative to backtracking RE engines
License:        BSD
URL:            http://github.com/google/re2/
Source0:        https://github.com/google/re2/archive/%{longver}/re2-%{longver}.tar.gz

BuildRequires: cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconf
BuildRequires:  abseil-cpp-devel
BuildRequires:  gtest-devel

%description
RE2 is a C++ library providing a fast, safe, thread-friendly alternative to
backtracking regular expression engines like those used in PCRE, Perl, and
Python.

Backtracking engines are typically full of features and convenient syntactic
sugar but can be forced into taking exponential amounts of time on even small
inputs.

In contrast, RE2 uses automata theory to guarantee that regular expression
searches run in time linear in the size of the input, at the expense of some
missing features (e.g back references and generalized assertions).

%package        devel
Summary:        C++ header files and library symbolic links for %{name}
Requires:       %{name}%{?_isa} = %{epoch}:%{version}-%{release}

%description    devel
This package contains the C++ header files and symbolic links to the shared
libraries for %{name}. If you would like to develop programs using %{name},
you will need to install %{name}-devel.

%prep
%setup -q -n %{name}-%{longver}

%build
# The RPM macro for the linker flags does not exist on EPEL
%{!?__global_ldflags: %global __global_ldflags -Wl,-z,relro}

%cmake . \
    -DOVERRIDE_INSTALL_PREFIX=/usr \
    -DCMAKE_COLOR_MAKEFILE:BOOL=OFF \
    -DINSTALL_LIBDIR:PATH=%{_libdir} \
    "-GUnix Makefiles"

%cmake_build

%install
%cmake_install

# Suppress the static library
rm -fv %{buildroot}%{_libdir}/libre2.a

%check
%make_build shared-test

%ldconfig_scriptlets

%files
%license LICENSE
%doc README *.md
%{_libdir}/libre2.so.11*

%files devel
%{_includedir}/re2/
%{_libdir}/libre2.so
%{_libdir}/pkgconfig/re2.pc
%{_libdir}/cmake/re2/*.cmake

%changelog
## START: Generated by rpmautospec
* Sat Feb 24 2024 Paul Wouters <paul.wouters@aiven.io> - 1:20240201-2
- Add BuildRequires for pkgconf, abseil-cpp-devel and gtest-devel

* Fri Feb 23 2024 Paul Wouters <paul.wouters@aiven.io> - 1:20240201-1
- Update to 2024-02-01. Use autochangelog

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1:20220601-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1:20220601-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1:20220601-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1:20220601-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Wed Nov 30 2022 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1:20220601-1
- clog

* Sat Jul 23 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1:20211101-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1:20211101-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Mon Jan 10 2022 Adam Williamson <awilliam@redhat.com> - 1:20211101-2
- Backport thread discovery patch, fix pkgconfig file (#2038572)

* Fri Jan 07 2022 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1:20211101-1
- Upgrade to 2021-11-01

* Thu Sep 16 2021 Kaleb S. KEITHLEY <kkeithle@redhat.com> - 1:20190801-6
- build with cmake to produce cmake style pkginfo that can be consumed by
  dependent packages

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1:20190801-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Mar 30 2021 Jonathan Wakely <jwakely@redhat.com> - 1:20190801-4
- Rebuilt for removed libstdc++ symbol (#1937698)

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1:20190801-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Fri Jan 08 2021 Tom Stellard <tstellar@redhat.com> - 1:20190801-2
- Add BuildRequires: make

* Wed Aug 26 2020 Jeff Law <law@redhat.com> - 1:20190801-1
- Restore accidentally dropped line

* Wed Aug 26 2020 Jeff Law <law@redhat.com> - 1:%{longver}-1
- No longer force C++11

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1:20190801-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1:20190801-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Wed Aug 14 2019 Rex Dieter <rdieter@gmail.com> - 1:20190801-3
- devel: use epoch in versioned dep

* Wed Aug 14 2019 Rex Dieter <rdieter@gmail.com> - 1:20190801-2
- devel use epoch in versioned dep

* Wed Aug 14 2019 Rex Dieter <rdieter@gmail.com> - 1:20190801-1
- 1:20190801-2 bump soname tighten %%files, track soname explicitly use
  %%make_build %%make_install macros Epoch:1 for upgrade path (from f29)

* Mon Aug 05 2019 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 20190801-2
- [Git] Ignored tarballs

* Sat Aug 03 2019 Lukas Vrabec <lvrabec@redhat.com> - 20190801-1
- update to 20190801

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 20160401-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 20160401-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Mon Jan 28 2019 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 20160401-10
- Remove obsolete Group tag

* Tue Jan 22 2019 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 20160401-9
- Remove obsolete ldconfig scriptlets

* Tue Jul 24 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 20160401-8
- Add missing BuildRequires on gcc-c++

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 20160401-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 20160401-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 20160401-5
- Rebuilt for
  https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 20160401-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 20160401-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Apr 29 2016 Tom Callaway <spot@fedoraproject.org> - 20160401-2
- force c++11

* Fri Apr 29 2016 Tom Callaway <spot@fedoraproject.org> - 20160401-1
- 2016-04-01

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 20131024-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jun 18 2015 Dennis Gilmore <dennis@ausil.us> - 20131024-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Apr 15 2015 Petr Písař <ppisar@redhat.com> - 20131024-4
- Rebuild owing to C++ ABI change in GCC-5

* Sun Aug 17 2014 Peter Robinson <pbrobinson@fedoraproject.org> - 20131024-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Dennis Gilmore <dennis@ausil.us> - 20131024-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Nov 12 2013 Tom Callaway <spot@fedoraproject.org> - 20131024-1
- update to 20131024, fix symbols issue

* Sun Aug 04 2013 Dennis Gilmore <dennis@ausil.us> - 20130115-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Feb 19 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 20130115-2
- [EPEL] Specified the __global_ldflags macro for EPEL (where it does not
  exist).

* Tue Feb 19 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 20130115-1
- Took into account the feedback from review request (#868578).
## END: Generated by rpmautospec
